function bez = computebez_mdds3d(deg,m1)
%computebez_mdds3d --> Evaluation of Bernstein-Bezier polynomials 
%                      on a regular tetrahedral grid.
%
%<Synopsis>
%  bez = computebez_mdds3d(deg,m1)
%
%<Description>
%  Computes the values of trivariate Bernstein-Bezier polynomials of  
%  degree deg on a regular tetrahedral grid.
%
%<Input Parameters>
%  deg  --> Box-spline degree
%   
%  m1   --> parameter identifing the number of evaluation points  
%           (m1+1) per tetrahedron edge
%
%<Output Parameters>
%  bez  --> bi-dimensional array containing the evaluations 
%           of all trivariate Bernstein-Bezier polynomials in   
%           all the N, N=(m1+1)*(m1+2)*(m1+3)/6, points in the 
%           tetrahedral grid.

%<Authors>
%  G. Casciola, Dept. of Mathematics - University of Bologna, Italy
%  E. Franchini, Dept. of Pure and Applied Mathematics - University of Padova, Italy
%  L. Romani, Dept. of Mathematics - University of Bologna, Italy
%
%  Last revision: March 22, 2006

% Number of Bernstein-Bezier polynomials per tetrahedron
G=(deg+1)*(deg+2)*(deg+3)/6;

% Initialization of indexes to be used in the evaluation procedure
R=zeros(1,deg*(deg+1)*(deg+2)/6);   
rr=1; R(1)=rr;
for h=2:deg   
    rr1=rr;
    rr=[rr1 h*ones(1,h)];
    ind=R>0;
    ind1=max(find(ind));
    R(ind1+1:length(rr)+ind1)=rr; 
end

u4=[1.0 0.0 0.0 0.0];
v4=[0.0 1.0 0.0 0.0];
w4=[0.0 0.0 1.0 0.0];
t4=[0.0 0.0 0.0 1.0];

np=0;
for k3=0:m1
    for k2=0:k3
        for k1=0:k2          
            r=((m1-k3)*u4(1) + (k3-k2)*v4(1) + (k2-k1)*w4(1) + k1*t4(1))/m1;
            s=((m1-k3)*u4(2) + (k3-k2)*v4(2) + (k2-k1)*w4(2) + k1*t4(2))/m1;
            t=((m1-k3)*u4(3) + (k3-k2)*v4(3) + (k2-k1)*w4(3) + k1*t4(3))/m1;
            u=((m1-k3)*u4(4) + (k3-k2)*v4(4) + (k2-k1)*w4(4) + k1*t4(4))/m1;            
            np=np+1;
            for ii=1:G
                v=zeros(G,1);
                v(ii)=1.0;                 
                for k=1:deg
                    ic=1;
                    for i=1:deg-k+1       
                        for j=1:i*(i+1)/2
                            ici=ic+i*(i+1)/2;
                            ici1=ici+R(ic);               
                            ici2=ici1+1;                             
                            v(ic)=r*v(ic)+s*v(ici)+t*v(ici1)+u*v(ici2);
                            ic=ic+1;
                        end
                    end           
                end                
                bez(np,ii)=v(1);
            end          
        end
    end
end