function [tetra,r,s,t,u] = findtetra_mdds3d(x,y,z)
%findtetra_mdds3d --> Determination of the tetrahedron type  
%                     containing the 3D evaluation point  
%                     chosen in the Box-spline domain.
%
%<Synopsis>
%  [tetra,r,s,t,u] = findtetra_mdds3d(x,y,z)
%
%<Description>
%  Determine in which tetrahedron of the trivariate Box-spline  
%  domain the evaluation point is contained.
%
%<Input Parameters>
%  x     --> first coordinate of the evaluation point 
%            mapped in [0,1]
%   
%  y     --> second coordinate of the evaluation point
%            mapped in [0,1] 
%   
%  z     --> third coordinate of the evaluation point
%            mapped in [0,1] 
%
%<Output Parameters>
%  tetra --> tetrahedron type (1,2,3,4,5 or 6) containing  
%            the evaluation point
%
%  r     --> first barycentric coordinate of the evaluation
%            point in the identified tetrahedron
%
%  s     --> second barycentric coordinate of the evaluation
%            point in the identified tetrahedron
%
%  t     --> third barycentric coordinate of the evaluation
%            point in the identified tetrahedron
%
%  u     --> fourth barycentric coordinate of the evaluation
%            point in the identified tetrahedron

%<Authors>
%  G. Casciola, Dept. of Mathematics - University of Bologna, Italy
%  E. Franchini, Dept. of Pure and Applied Mathematics - University of Padova, Italy
%  L. Romani, Dept. of Mathematics - University of Bologna, Italy
%
%  Last revision: March 22, 2006

if ((z-y)>=0) & ((x-y)>=0) & ((z-x)<=0)
    % Tetrahedron type "1"
    tetra=1;
    % Barycentric coordinates computation
    r=y;
    s=1-x;
    t=x-z;
    u=z-y;    
elseif ((z-y)<=0) & ((x-y)>=0) & ((z-x)<=0)
    % Tetrahedron type "2"
    tetra=2;
    % Barycentric coordinates computation
    r=z;
    s=y-z;
    t=x-y;
    u=1-x;  
elseif ((z-y)<=0) & ((x-y)<=0) & ((z-x)<=0)
    % Tetrahedron type "3"
    tetra=3;
    % Barycentric coordinates computation
    r=z;
    s=x-z;
    t=y-x;
    u=1-y;   
elseif ((z-y)<=0) & ((x-y)<=0) & ((z-x)>=0)
    % Tetrahedron type "4"
    tetra=4;
    % Barycentric coordinates computation
    r=x;
    s=1-y;
    t=y-z;
    u=z-x;    
elseif ((z-y)>=0) & ((x-y)<=0) & ((z-x)>=0)
    % Tetrahedron type "5"
    tetra=5;
    % Barycentric coordinates computation
    r=1-z;
    s=x;
    t=y-x;
    u=z-y;    
elseif ((z-y)>=0) & ((x-y)>=0) & ((z-x)>=0)
    % Tetrahedron type "6"
    tetra=6;
    % Barycentric coordinates computation
    r=1-z;
    s=y;
    t=x-y;
    u=z-x;
end