function A = step1_mdds2d(k,B)
%step1_mdds2d --> Computation of differences-summations 
%                   along direction e_1=[1 0]'.
%
%<Synopsis>
%  A = step1_mdds2d(k,B)
%
%<Description>
%  To compute the Bezier net coefficients of the bivariate 
%  three-direction Box-spline with multiplicities vector nu=[k 1 1], 
%  we generate the mixed directions that will be used for defining the 
%  integration paths on the coefficients in B. Here, B is a 
%  bi-dimensional array with the Bezier coefficients of the bivariate 
%  three-direction Box-spline with multiplicities vector [k-1 1 1]. 
%
%<Input Parameters>
%   k --> nu(1) (multiplicity of direction e_1=[1 0]')
%   B --> bi-dimensional array with the Bezier coefficients of
%         the bivariate three-direction Box-spline with multiplicities
%         vector [k-1 1 1]
%
% <Output Parameters>  
%   A --> bi-dimensional array with the Bezier coefficients of
%         the bivariate three-direction Box-spline with multiplicities
%         vector [k 1 1]

%<Algorithm> 
%  First apply the shifting and subtracting procedure on the 
%  coefficients in B. Then compute the mixed directions that will be 
%  used for defining the integration paths on the new coefficients in B.
%
%<Authors>
%  G. Casciola, Dept. of Mathematics - University of Bologna, Italy
%  E. Franchini, Dept. of Pure and Applied Mathematics - University of Padova, Italy
%  L. Romani, Dept. of Mathematics - University of Bologna, Italy
%
%  Last revision: March 22, 2006

% Box-spline degree
m=k;

% Shifting and subtracting procedure on the Bezier coefficients in B
[r,col]=size(B);
dB=m-1;
B=[B zeros(r,dB)]-[zeros(r,dB) B];

mm=m+1;
A=zeros(2*m+1,m*mm+1);


% Computation of the mixed directions that will be used for defining 
% the integration paths on the new coefficients in B

% Mixed direction in R
%---------------------------------------------------------------
A(mm,:)=integ_mdds(dupl_mdds(B(m,:),m,1,k));

% Direction pattern for the generation of mixed directions in R^2
t=[zeros(1,m-2) 1 ones(1,m-2)];

% Mixed directions in R^2
%---------------------------------------------------------------
for g=0:1
    x=g*dB+2;
    for r=0:dB-1
        rr=r+1;
        d=dB+r;
        h=1;
        j=1;
        xx=r+x;
        for p=0:k
            f(h)=B(xx,j);
            h=h+1;
            for v=rr:d
                j=j+1;
                f(h)=B(xx-t(v),j);                
                h=h+1;
            end
        end    
        A(xx+g,:)=integ_mdds(f);
    end
end