function A = step1_mdds3d(k,B) 
%step1_mdds3d --> Computation of differences-summations 
%                 along direction e_1=[1 0 0]'.
%
%<Synopsis>
%  A = step1_mdds3d(k,B)
%
%<Description>
%  To compute the Bezier net coefficients of the trivariate 
%  four-direction Box-spline with multiplicities vector nu=[k 1 1 1], 
%  we generate the mixed directions that will be used for defining the 
%  integration paths on the coefficients in B. Here, B is a 
%  tri-dimensional array with the Bezier coefficients of the trivariate 
%  four-direction Box-spline with multiplicities vector [k-1 1 1 1]. 
%
%<Input Parameters>
%   k --> nu(1) (multiplicity of direction e_1=[1 0 0]')
%   B --> tri-dimensional array with the Bezier coefficients of
%         the trivariate four-direction Box-spline with multiplicities
%         vector [k-1 1 1 1]
%
%<Output Parameters>  
%   A --> tri-dimensional array with the Bezier coefficients of
%         the trivariate four-direction Box-spline with multiplicities
%         vector [k 1 1 1]

%<Algorithm> 
%  First apply the shifting and subtracting procedure on the 
%  coefficients in B. Then compute the mixed directions that will be 
%  used for defining the integration paths on the new coefficients in B.
%
%<Authors>
%  G. Casciola, Dept. of Mathematics - University of Bologna, Italy
%  E. Franchini, Dept. of Pure and Applied Mathematics - University of Padova, Italy
%  L. Romani, Dept. of Mathematics - University of Bologna, Italy
%
%  Last revision: March 22, 2006

% Box-spline degree
m=k;

% Shifting and subtracting procedure on the Bezier coefficients in B
[rB,colB,col1B]=size(B);
dB=m-1;
B=[B zeros(rB,dB,col1B)]-[zeros(rB,dB,col1B) B];

mm=m+1;
rA=2*m+1;
colA=m*mm+1;
A=zeros(rA,colA,rA);

ddB=dB-1;

% Computation of the mixed directions that will be used for defining 
% the integration paths on the new coefficients in B

% Mixed direction in R
%------------------------------------------------
A(mm,:,mm)=integ_mdds(dupl_mdds(B(m,:,m),m,1,k));

% Direction pattern for the generation of mixed directions in R^2 and R^3
t=[zeros(1,ddB) ones(1,dB)];

% Mixed directions in R^2 (on the plane y=const)
%------------------------------------------------
for g=0:1
    for r=0:ddB
        rr=r+1;
        r2=rr+1;
        d=dB+r;
        h=0;
        i=r2+g*dB;
        j=1;
        for p=0:k
            h=h+1;
            f(h)=B(i,j,m);
            for v=rr:d
                f(h+1)=B(i-t(v),j+1,m);
                j=j+1;
                h=h+1;
            end
        end    
        A(r2+g*m,:,mm)=integ_mdds(f);    
    end
end
 
for g1=0:1
    for r1=0:ddB

       % Mixed directions in R^2 (on the plane z=const)
       %----------------------------------------------
        h=0;
        j=1;
        mat=m+r1-g1*dB;
        for p=0:k
            h=h+1;
            f(h)=B(m,j,mat);      
            for v=dB-r1:2*dB-r1-1
                f(h+1)=B(m,j+1,mat+t(v));          
                j=j+1;
                h=h+1;
            end
        end    
        A(mm,:,2+(1-g1)*m+r1)=integ_mdds(f);

       % Mixed directions in R^3
       %---------------------------------------------------
        for g=0:1
            for r=0:ddB
                h=0;
                i=m-r+g*dB;
                j=1;
                mat=m+r1-g1*dB;
                for p=0:k
                    h=h+1;
                    f(h)=B(i,j,mat);
                    for v=dB-r:2*dB-r-1 
                        f(h+1)=B(i-t(v),j+1,mat+t(v+r-r1)); 
                        j=j+1;
                        h=h+1;
                    end
                end    
                A(m+g*m-r,:,2+(1-g1)*m+r1)=integ_mdds(f);
            end
        end
    end
end