function visual_mdds2d(nu,flag,m)
%visual_mdds2d --> Visualization of any bivariate three-direction
%                  Box-spline either through its surface graph or
%                  its B-net representation.
%
%<Synopsis>
%  visual_mdds2d(nu)
%  visual_mdds2d(nu,flag)
%  visual_mdds2d(nu,flag,m)
%
%<Description>
%  Exploits the mixed directional difference-summation 
%  algorithm (MDDS) generating the Bezier net of a 
%  bivariate three-direction Box-spline associated with 
%  the direction matrix D
%
%          nu(1)          nu(2)          nu(3)          
%      ------^------  ------^------  -------^-------  
%   D=[e_1, ..., e_1, e_2, ..., e_2, e_12, ..., e_12]
%
%  to visualize either its surface graph or its B-net.
%
%<Input Parameters>      
%  nu   --> 3-component vector with the multiplicities of the directions
%           e_1=[1 0]', e_2=[0 1]', e_12=[1 1]':
%           nu(1) multiplicity of direction e_1
%           nu(2) multiplicity of direction e_2
%           nu(3) multiplicity of direction e_12
%
%  flag --> parameter that indicates the kind of visualization:
%           flag=1  Box-spline surface visualization
%           flag=2  Bezier net visualization
%           flag=3  Box-spline surface and Bezier net visualization
%           Default flag = 3.
%
%  m    --> parameter identifing the number of evaluation points (m+1) 
%           per triangle edge (i.e. per unit square edge).
%           Default m = 10.
%
%<See Also>
%  visual_mdds3d --> Visualization of any trivariate four-direction
%  Box-spline.

%<Algorithm>
%  First we compute the B-net coefficients of the bivariate three-direction
%  Box-spline associated with the multiplicity vector nu. Then we evaluate  
%  the bivariate Bernstein-Bezier polynomials on a regular triangular grid
%  and compute the values of the Box-spline surface over each one of the two
%  triangles obtained by considering the tessellation of the unit square
%  proposed in Fig.2 right (see [1]). Successively we exploit the Matlab 
%  functions trisurf() and trimesh() to visualize respectively the Box-spline 
%  surface and its Bezier net.
%
%<Reference>
%  [1] G. Casciola, E. Franchini, L. Romani, "The mixed directional 
%      difference-summation algorithm for generating the Bezier net of a 
%      trivariate four-direction Box-spline"
%      Numerical Algorithms 43 (2006), pp. 75-98.
%
%<Authors>
%  G. Casciola, Dept. of Mathematics - University of Bologna, Italy
%  E. Franchini, Dept. of Pure and Applied Mathematics - University of Padova, Italy
%  L. Romani, Dept. of Mathematics - University of Bologna, Italy
%
%  Last revision: March 22, 2006

% Check the required input arguments
if nargin < 1
    error('Not enough input arguments.')
elseif nargin > 3
    error('Too many input arguments.')    
end

% Check the optional input arguments, and set defaults
if nargin < 3
    m=10;
end
if nargin < 2
    flag=3;
end

% Box-spline degree
deg=sum(nu)-2;
mm1=[m,deg];

% B-net computation
A=bnet_mdds(nu)./(factorial(deg));
switch flag
       case 1
            fig1=1;
            fig2=1;
       case 2
            fig1=2;
            fig2=2;
       case 3
            fig1=1;
            fig2=2;
end
for c=fig1:fig2
    npt=0;
    npol=0;
    cont=0;
    m1=mm1(c);
    if c==1    
       % Number of evaluation points in each triangle 
       num=(m1+1)*(m1+2)/2;
       % Evaluation of bivariate Bernstein-Bezier polynomials on a regular 
       % triangular grid
       bez=computebez_mdds2d(deg,m1);
    end
    for j=nu(2)+nu(3):-1:1
        for i=0:nu(1)+nu(3)-1  
            % Bezier coefficients of the two triangular patches contained  
            % in the square region identified by indexes i and j
            A1 = A(deg*(nu(2)+nu(3)-j)+1:deg*(nu(2)+nu(3)-j+1)+1, ...
                deg*i+1:deg*(i+1)+1);
            %--------------------------------------------------------------
            % Remove type 1 triangles respectively from the bottom and the 
            % top part outside the Box-spline domain 
            if not ( ( j<=nu(3)-1 & i>=nu(1)+1 & i-j>=nu(1) ) | ...
                    ( i<=nu(3)-1 & j>=nu(2)+1 & j-i>=(nu(2)+1) ) )
               cont=cont+1;
               % Definition of triangle type 1 (down)      
               u2=[i j];
               v2=[i+1 j];
               w2=[i j-1];
               mj1=npt;
               for k2=0:m1
                   for k1=0:m1-k2
                       npt=npt+1;  
                       x(npt)=((m1-k1-k2)*u2(1) + k1*v2(1) + k2*w2(1))/m1;
                       y(npt)=((m1-k1-k2)*u2(2) + k1*v2(2) + k2*w2(2))/m1;
                   end
               end
               if c==1
                  %Evaluation procedure
                  kk=0;
                  for ii=deg+1:-1:1
                      for jj=deg-ii+2:-1:1
                          kk=kk+1;
                          b(kk,1)=A1(ii,jj);
                      end
                  end
                  val(1+num*(cont-1):num*cont)=bez*b;
               end
               for jj=1:m1
                   mj=mj1+m1+1-jj+1;
                   for k=1:m1-jj+1
                       npol=npol+1;
                       TRI(npol,1)=mj1+k;
                       TRI(npol,2)=mj1+k+1;
                       TRI(npol,3)=mj+k;
                       if k<m1+1-jj
                          npol=npol+1;
                          TRI(npol,1)=mj1+k+1;
                          TRI(npol,2)=mj+k+1;
                          TRI(npol,3)=mj+k;
                       end
                   end
                   mj1=mj;
               end
           end
           %---------------------------------------------------------------
           % Remove type 2 triangles respectively from the bottom and the 
           % top part outside the Box-spline domain 
           if not ( ( j<=nu(3) & i>=nu(1) & i-j>=nu(1)-1) | ...
                   ( i<=nu(3)-1 & j>nu(2) & j-i>(nu(2)+1) ) )
              cont=cont+1;
              % Definition of triangle type 2 (up)   
              u2=[i+1 j-1];
              v2=[i+1 j];
              w2=[i j-1];
              mj1=npt;
              for k2=0:m1
                  for k1=0:m1-k2
                      npt=npt+1;  
                      x(npt)=((m1-k1-k2)*u2(1) + k1*v2(1) + k2*w2(1))/m1;
                      y(npt)=((m1-k1-k2)*u2(2) + k1*v2(2) + k2*w2(2))/m1;
                  end
              end
              if c==1
                 % Evaluation procedure
                 kk=0;
                 for jj=1:deg+1
                     for ii=deg+2-jj:deg+1
                         kk=kk+1;
                         b(kk,1)=A1(ii,jj);
                     end
                 end
                 val(1+num*(cont-1):num*cont)=bez*b;
              end
              for jj=1:m1
                  mj=mj1+m1+1-jj+1;
                  for k=1:m1-jj+1
                      npol=npol+1;
                      TRI(npol,1)=mj1+k;
                      TRI(npol,2)=mj1+k+1;
                      TRI(npol,3)=mj+k;
                      if k<m1+1-jj
                         npol=npol+1;
                         TRI(npol,1)=mj1+k+1;
                         TRI(npol,2)=mj+k+1;
                         TRI(npol,3)=mj+k;
                      end
                   end
                   mj1=mj;
              end
           end 
        end
    end
   
    [rnu,cnu]=size(nu);
    if cnu==1
        nu=nu';
    end
    
    figure(c) 
    clf
    if c == 1 
       trisurf(TRI,x,y,val);
       colormap(cool);
       shading faceted;
       
       title(['Box-spline Surface  nu=[',num2str(nu),']']);
       xlabel('x');    
       ylabel('y');
       zlabel('z');
       clear x y TRI
    else
       my=max(y); 
       mx=min(x);
       for i=1:npt
           b(i)=A(fix(deg*(my-y(i))+1),fix(deg*(mx+x(i))+1));
       end
       trimesh(TRI,x,y,b);
       colormap(cool);
       shading faceted;
       title(['Box-spline B-net  nu=[',num2str(nu),']']);
       xlabel('x');    
       ylabel('y');
       zlabel('z');
    end
end
